pub struct MigrationReport {
pub migrated: usize,
pub skipped: usize,
}Expand description
The one-time startup migration report returned by migrate_legacy_session_layout.
Fields
migrated: usizeNumber of legacy session directories moved up one level to the fixed (#5981) layout.
skipped: usizeNumber of legacy session directories left in place because a directory already existed at the destination (not clobbered — it may already have been recreated at the new path).